======================
Examples and Tutorials
======================

`Examples`_ files on how to use some of the functions

.. _Examples: https://github.com/CenterForTheBuiltEnvironment/pythermalcomfort/tree/master/examples

YouTube `tutorials`_ playlist

.. _tutorials: https://www.youtube.com/playlist?list=PLY91jl6VVD7zMaJjRVrVkaBtI56U7ztQC

.. raw:: html

    <div style="margin-bottom:2rem">
        <iframe id="ytplayer" type="text/html" width="100%" height="360"
      src="https://www.youtube.com/embed?listType=playlist&list=PLY91jl6VVD7zMaJjRVrVkaBtI56U7ztQC"
      frameborder="0"></iframe>
    </div>
